@@ -8,6 +8,7 @@ from mim.click import OptionEatAll, get_downstream_package, param2lowercase
 from mim.commands.search import get_model_info
 from mim.utils import (
     DEFAULT_CACHE_DIR,
+    PKG2MODULE,
     download_from_file,
     echo_success,
     highlighted_error,
@@ -61,12 +62,14 @@ def download(package: str,
 
     package, version = split_package_version(package)
     if version:
-        raise ValueError('version is not allowed, please type '
-                         '"mim download -h" to show the correct way.')
+        raise ValueError(
+            highlighted_error('version is not allowed, please type '
+                              '"mim download -h" to show the correct way.'))
 
     if not is_installed(package):
-        raise RuntimeError(f'{package} is not installed. Please install it '
-                           'first.')
+        raise RuntimeError(
+            highlighted_error(f'{package} is not installed. Please install it '
+                              'first.'))
 
     checkpoints = []
     model_info = get_model_info(
@@ -74,8 +77,9 @@ def download(package: str,
     valid_configs = model_info.keys()
     invalid_configs = set(configs) - set(valid_configs)
     if invalid_configs:
-        raise ValueError(f'Expected configs: {valid_configs}, but got '
-                         f'{invalid_configs}')
+        raise ValueError(
+            highlighted_error(f'Expected configs: {valid_configs}, but got '
+                              f'{invalid_configs}'))
 
     from mmcv import Config
 
@@ -97,7 +101,8 @@ def download(package: str,
 
         config_paths = model_info[config]['config']
         for config_path in config_paths.split(','):
-            config_path = resource_filename(package, config_path)
+            module_name = PKG2MODULE.get(package, package)
+            config_path = resource_filename(module_name, config_path)
             if not osp.exists(config_path):
                 raise ValueError(
                     highlighted_error(f'{config_path} is not found.'))
