@@ -19,6 +19,7 @@ from mim.utils import (
     get_installed_path,
     highlighted_error,
     is_installed,
+    module_full_name,
     recursively_find,
     set_config,
     string2args,
@@ -32,6 +33,7 @@ from mim.utils import (
 @click.argument('package', type=str)
 @click.argument('config', type=str)
 @click.option(
+    '-l',
     '--launcher',
     type=click.Choice(['none', 'pytorch', 'slurm'], case_sensitive=False),
     default='none',
@@ -42,24 +44,30 @@ from mim.utils import (
     default=29500,
     help=('The port used for inter-process communication '
           '(only applicable to slurm / pytorch launchers)'))
-@click.option('--gpus', type=int, default=1, help='Number of gpus to use')
 @click.option(
+    '-G', '--gpus', type=int, default=1, help='Number of gpus to use')
+@click.option(
+    '-g',
     '--gpus-per-node',
     type=int,
     help=('Number of gpus per node to use '
           '(only applicable to launcher == "slurm")'))
 @click.option(
+    '-c',
     '--cpus-per-task',
     type=int,
     default=2,
     help='Number of cpus per task (only applicable to launcher == "slurm")')
 @click.option(
+    '-p',
     '--partition',
     type=str,
     help='The partition to use (only applicable to launcher == "slurm")')
-@click.option('--max-jobs', type=int, help='Max parallel number', default=1)
+@click.option(
+    '-j', '--max-jobs', type=int, help='Max parallel number', default=1)
 @click.option(
     '--srun-args', type=str, help='Other srun arguments that might be used')
+@click.option('-y', '--yes', is_flag=True, help='Don’t ask for confirmation.')
 @click.option(
     '--search-args', type=str, help='Arguments for hyper parameters search')
 @click.argument('other_args', nargs=-1, type=click.UNPROCESSED)
@@ -74,12 +82,18 @@ def cli(package: str,
         port: int = 29500,
         srun_args: Optional[str] = None,
         search_args: str = '',
+        yes: bool = False,
         other_args: tuple = ()) -> None:
     """Perform Hyper-parameter search.
 
     Example:
 
     \b
+    # Parameter search on a single server with CPU by setting `gpus` to 0 and
+    # 'launcher' to 'none' (if applicable). The training script of the
+    # corresponding codebase will fail if it doesn't support CPU training.
+    > mim gridsearch mmcls resnet101_b16x8_cifar10.py --work-dir tmp --gpus \
+        0 --search-args '--optimizer.lr 1e-2 1e-3'
     # Parameter search with on a single server with one GPU, search learning
     # rate
     > mim gridsearch mmcls resnet101_b16x8_cifar10.py --work-dir tmp --gpus \
@@ -124,6 +138,7 @@ def cli(package: str,
         port=port,
         srun_args=srun_args,
         search_args=search_args,
+        yes=yes,
         other_args=other_args)
 
     if is_success:
@@ -144,6 +159,7 @@ def gridsearch(
     port: int = 29500,
     srun_args: Optional[str] = None,
     search_args: str = '',
+    yes: bool = True,
     other_args: tuple = ()
 ) -> Tuple[bool, Union[str, Exception]]:
     """Hyper parameter search with given config.
@@ -169,9 +185,16 @@ def gridsearch(
             used, all arguments should be in a string. Defaults to None.
         search_args (str, optional): Arguments for hyper parameters search, all
             arguments should be in a string. Defaults to None.
+        yes (bool): Don’t ask for confirmation. Default: True.
         other_args (tuple, optional): Other arguments, will be passed to the
             codebase's training script. Defaults to ().
     """
+    full_name = module_full_name(package)
+    if full_name == '':
+        msg = f"Can't determine a unique package given abbreviation {package}"
+        raise ValueError(highlighted_error(msg))
+    package = full_name
+
     # If launcher == "slurm", must have following args
     if launcher == 'slurm':
         msg = ('If launcher is slurm, '
@@ -183,7 +206,7 @@ def gridsearch(
     if not is_installed(package):
         msg = (f'The codebase {package} is not installed, '
                'do you want to install it? ')
-        if click.confirm(msg):
+        if yes or click.confirm(msg):
             click.echo(f'Installing {package}')
             cmd = ['mim', 'install', package]
             ret = subprocess.check_call(cmd)
@@ -239,10 +262,13 @@ def gridsearch(
     cfg = Config.fromfile(config)
     for arg in search_args_dict:
         try:
-            arg_type = type(get_config(cfg, arg))
-            search_args_dict[arg] = [eval(x) for x in search_args_dict[arg]]
-            for val in search_args_dict[arg]:
-                assert type(val) == arg_type
+            arg_value = get_config(cfg, arg)
+            if arg_value and not isinstance(arg_value, str):
+                search_args_dict[arg] = [
+                    eval(x) for x in search_args_dict[arg]
+                ]
+                for val in search_args_dict[arg]:
+                    assert type(val) == type(arg_value)
         except AssertionError:
             msg = f'Arg {arg} not in the config file. '
             raise AssertionError(highlighted_error(msg))
@@ -304,8 +330,14 @@ def gridsearch(
         common_args = ['--launcher', launcher] + other_args_str.split()
 
         if launcher == 'none':
-            cmd = ['python', train_script, config_path, '--gpus',
-                   str(gpus)] + common_args
+            if gpus:
+                cmd = [
+                    'python', train_script, config_path, '--gpus',
+                    str(gpus)
+                ] + common_args
+            else:
+                cmd = ['python', train_script, config_path, '--device', 'cpu'
+                       ] + common_args
         elif launcher == 'pytorch':
             cmd = [
                 'python', '-m', 'torch.distributed.launch',
