@@ -1,5 +1,5 @@
 import os
-import site
+import pkg_resources
 
 USER = 'open-mmlab'
 DEFAULT_URL = f'https://github.com/{USER}'
@@ -23,13 +23,23 @@ PKG2PROJECT = {
     'mmocr': 'mmocr',
     'mmgen': 'mmgeneration',
 }
-PKG_ALIAS = {
+# TODO: Should directly infer MODULE name from PKG info
+PKG2MODULE = {
     'mmcv-full': 'mmcv',
-    'mmcv': 'mmcv',
+    'mmaction2': 'mmaction',
+    'mmsegmentation': 'mmseg',
+}
+MODULE2PKG = {
+    'mmaction': 'mmaction2',
+    'mmseg': 'mmsegmentation',
 }
 
 DEFAULT_CACHE_DIR = f'{os.environ["HOME"]}/.cache/mim'
 if not os.path.exists(DEFAULT_CACHE_DIR):
     os.makedirs(DEFAULT_CACHE_DIR)
 
-MMPACKAGE_PATH = os.path.join(site.getsitepackages()[0], 'mmpackage.txt')
+# Although site.getsitepackage() can also get the directory of site-packages,
+# it will faild in virtualenv. It is an issue with virtualenv, which copies
+# the bundled version of site.py to the venv when it is created.
+MMPACKAGE_PATH = os.path.join(
+    pkg_resources.get_distribution('click').location, 'mmpackage.txt')
